@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::JSAN::Bundle;
 BEGIN {
-  $Dist::Zilla::Plugin::JSAN::Bundle::VERSION = '0.05';
+  $Dist::Zilla::Plugin::JSAN::Bundle::VERSION = '0.06';
 }
 
 # ABSTRACT: Bundle the library files into "tasks", using information from Components.JS 
@@ -23,6 +23,11 @@ has 'npm_root' => (
 );
 
 
+has 'roots_only_for_release' => (
+    is      => 'rw',
+    default => 1
+);
+
 
 #================================================================================================================================================================================================================================================
 sub gather_files {
@@ -45,8 +50,10 @@ sub munge_files {
     $components = $1;
 
     my $deploys = decode_json $components;
-    
-    $self->concatenate_for_task($deploys, 'all');
+
+    foreach my $deploy (keys(%$deploys)) {
+        $self->concatenate_for_task($deploys, $deploy);
+    }
 }
 
 
@@ -54,35 +61,41 @@ sub munge_files {
 sub concatenate_for_task {
     my ($self, $deploys, $task_name) = @_;
     
-    if ($task_name eq 'all') {
-    	
-    	foreach my $deploy (keys(%$deploys)) {
-    		$self->concatenate_for_task($deploys, $deploy);  	
-    	}
+    my @components = $self->expand_task_entry($deploys, $task_name);
+    die "No components in task: [$task_name]" unless @components > 0;
     
-    } else {
-	    my @components = $self->expand_task_entry($deploys, $task_name);
-	    die "No components in task: [$task_name]" unless @components > 0;
-	    
-	    my @dist_dirs = split /-/, $self->zilla->name;
-	    push @dist_dirs, $task_name;
-	    $dist_dirs[-1] .= '.js';
-	    
+    my @dist_dirs = split /-/, $self->zilla->name;
+    push @dist_dirs, $task_name;
+    $dist_dirs[-1] .= '.js';
+    
+    my $generate    = sub {
+        my $bundle_content = ''; 
+        
+        foreach my $comp (@components) {
+            $bundle_content .= $self->get_component_content($comp) . ";\n";
+        }
+        
+        return $bundle_content;
+    };
+    
+    $self->add_file(Dist::Zilla::File::FromCode->new({
+        
+        name => file('lib', 'Task', @dist_dirs) . '',
+        
+        code => $generate
+    }));
+    
+    if (!$self->roots_only_for_release || $ENV{ DZIL_RELEASING }) {
+    
+        my $root_file_name = join("-", 'task', map { lc } @dist_dirs);
+        
         $self->add_file(Dist::Zilla::File::FromCode->new({
             
-            name => file('lib', 'Task', @dist_dirs) . '',
+            name => file($root_file_name) . '',
             
-            code => sub {
-        	    my $bundle_content = ''; 
-        	    
-        	    foreach my $comp (@components) {
-        	        $bundle_content .= $self->get_component_content($comp) . ";\n";
-        	    }
-        	    
-        	    return $bundle_content;
-            }
+            code => $generate
         }));
-    };
+    }
 }
 
 
@@ -138,8 +151,7 @@ sub get_npm_root {
     
     $self->log('Trying to determine the `root` config setting of `npm`');
     
-    # JSANLIB is deprecated
-    my $root = $ENV{npm_config_root} || $ENV{JSANLIB};
+    my $root = $ENV{npm_config_root};
     
     if ($root) {
         
@@ -153,7 +165,7 @@ sub get_npm_root {
     my $exit_code;
     
     my ($stdout, $stderr) = capture {
-        system('npm config get root');
+        system('npm root -g');
         
         $exit_code = $? >> 8;
     };
@@ -218,7 +230,7 @@ Dist::Zilla::Plugin::JSAN::Bundle - Bundle the library files into "tasks", using
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -281,7 +293,8 @@ All other entries denotes the javascript files from the "lib" directory. For exa
 as the content of the file "lib/KiokuJS/Reference.js"
 
 All bundles are stored as "lib/Task/Distribution/Name/BundleName.js", assuming the name of the distrubution is "Distribution-Name"
-and name of bundle - "BundleName".
+and name of bundle - "BundleName". During release, all bundles also gets added to the root of distribution as
+"task-distribution-name-bundlename.js". To enable the latter feature for regular builds add the `roots_only_for_release = 0` config option  
 
 =head1 AUTHOR
 
